get_tags.RdFunction reading a document and retrieving the tags listed in the meta-information at the end.
get_tags(path)character. Path to the document for which meta-information should be retrieved.
A single-row tibble with all the tags from a document.